diff --git a/README.md b/README.md
index cfde744f3..390928519 100755
--- a/README.md
+++ b/README.md
@@ -201,6 +201,8 @@ For previous versions, please read:
## V3 changes
+* v3.0, 2020-10-10, [3.0 release1(3.0.144)][r3.0r1] released. 122674 lines.
+* v3.0, 2020-10-10, Fix [#1780][bug #1780], build fail on Ubuntu20(focal). 3.0.144
* v3.0, 2020-09-14, Prevent stop ingest for multiple times. 3.0.143
* v3.0, 2020-09-10, RTC: Change SO_REUSEPORT fail to warning. 3.0.142
* v3.0, 2020-06-27, [3.0 release0(3.0.141)][r3.0r0] released. 122674 lines.
@@ -818,6 +820,7 @@ For previous versions, please read:
## Releases
+* 2020-10-10, [Release v3.0-r1][r3.0r1], 3.0 release1, 3.0.144, 122674 lines.
* 2020-06-27, [Release v3.0-r0][r3.0r0], 3.0 release0, 3.0.141, 122674 lines.
* 2020-03-29, [Release v3.0-b3][r3.0b4], 3.0 beta4, 3.0.139, 122674 lines.
* 2020-03-18, [Release v3.0-b3][r3.0b3], 3.0 beta3, 3.0.134, 122509 lines.
@@ -1759,6 +1762,7 @@ Winlin
[bug #1651]: https://github.com/ossrs/srs/issues/1651
[bug #1619]: https://github.com/ossrs/srs/issues/1619
[bug #1629]: https://github.com/ossrs/srs/issues/1629
+[bug #1780]: https://github.com/ossrs/srs/issues/1780
[bug #yyyyyyyyyyyyy]: https://github.com/ossrs/srs/issues/yyyyyyyyyyyyy
[bug #1631]: https://github.com/ossrs/srs/issues/1631
@@ -1770,6 +1774,7 @@ Winlin
[exo #828]: https://github.com/google/ExoPlayer/pull/828
+[r3.0r1]: https://github.com/ossrs/srs/releases/tag/v3.0-r1
[r3.0r0]: https://github.com/ossrs/srs/releases/tag/v3.0-r0
[r3.0b4]: https://github.com/ossrs/srs/releases/tag/v3.0-b4
[r3.0b3]: https://github.com/ossrs/srs/releases/tag/v3.0-b3
diff --git a/trunk/src/core/srs_core.hpp b/trunk/src/core/srs_core.hpp
index e3dd74ce9..0fbe07c39 100644
--- a/trunk/src/core/srs_core.hpp
+++ b/trunk/src/core/srs_core.hpp
@@ -50,7 +50,7 @@
// The current stable release.
#define VERSION_STABLE 3
-#define VERSION_STABLE_BRANCH SRS_XSTR(VERSION_STABLE)".0release"
+#define VERSION_STABLE_BRANCH SRS_XSTR(VERSION_STABLE) ".0release"
// For 32bit os, 2G big file limit for unistd io,
// ie. read/write/lseek to use 64bits size for huge file.
diff --git a/trunk/src/core/srs_core_version3.hpp b/trunk/src/core/srs_core_version3.hpp
index b5a54ac4b..ef1590d42 100644
--- a/trunk/src/core/srs_core_version3.hpp
+++ b/trunk/src/core/srs_core_version3.hpp
@@ -24,6 +24,6 @@
#ifndef SRS_CORE_VERSION3_HPP
#define SRS_CORE_VERSION3_HPP
-#define SRS_VERSION3_REVISION 143
+#define SRS_VERSION3_REVISION 144
#endif
diff --git a/trunk/src/kernel/srs_kernel_utility.cpp b/trunk/src/kernel/srs_kernel_utility.cpp
index 73ae0c75f..4af0defa6 100644
--- a/trunk/src/kernel/srs_kernel_utility.cpp
+++ b/trunk/src/kernel/srs_kernel_utility.cpp
@@ -125,7 +125,7 @@ srs_utime_t srs_get_system_startup_time()
// For utest to mock it.
#ifndef SRS_OSX
-_srs_gettimeofday_t _srs_gettimeofday = ::gettimeofday;
+_srs_gettimeofday_t _srs_gettimeofday = (_srs_gettimeofday_t)::gettimeofday;
#endif
srs_utime_t srs_update_system_time()
diff --git a/trunk/src/main/srs_main_server.cpp b/trunk/src/main/srs_main_server.cpp
index 6ec4d01f7..d2095754e 100644
--- a/trunk/src/main/srs_main_server.cpp
+++ b/trunk/src/main/srs_main_server.cpp
@@ -358,8 +358,8 @@ void show_macro_features()
#endif
#if VERSION_MAJOR > VERSION_STABLE
- #warning "Current branch is develop."
- srs_warn("%s/%s is develop", RTMP_SIG_SRS_KEY, RTMP_SIG_SRS_VERSION);
+ #warning "Current branch is not stable."
+ srs_warn("%s/%s is not stable", RTMP_SIG_SRS_KEY, RTMP_SIG_SRS_VERSION);
#endif
#if defined(SRS_PERF_SO_SNDBUF_SIZE) && !defined(SRS_PERF_MW_SO_SNDBUF)